@@ -1,5 +1,6 @@
 sub Mojo::Weixin::_logout {
     my $self = shift;
+    $self->info("客户端正在注销...");
     my $type = shift || 0;
     my $api = "https://". $self->domain ."/cgi-bin/mmwebwx-bin/webwxlogout";
     my @query_string = (
@@ -12,5 +13,7 @@ sub Mojo::Weixin::_logout {
         uin => $self->wxuin,
     };
     $self->http_post($self->gen_url($api,@query_string),{ua_debug_res_body=>0,Referer=>"https://". $self->domain . "/"},form=>$post,);
+    $self->clear_cookie();
+    return 1;
 }
 1;
