@@ -20,6 +20,7 @@ sub call{
 
     if(defined $data->{poll_api}){
         $client->on('_mojo_weixin_plugin_openwx_poll_over' => sub{
+            $client->debug("发起poll_api[$data->{poll_api}]心跳请求...");
             $client->http_get($data->{poll_api},sub{
                 $client->timer($data->{poll_interval} || 5,sub {$client->emit('_mojo_weixin_plugin_openwx_poll_over');});
             });
@@ -38,7 +39,7 @@ sub call{
             $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             if(defined $data->{post_api}){
                 my($data,$ua,$tx) = $client->http_post($data->{post_api},{ua_connect_timeout=>5,ua_request_timeout=>5,ua_inactivity_timeout=>5,ua_retry_times=>1},json=>$post_json);
-                if($tx->result->is_success){
+                if($tx->res->is_success){
                     $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "](@args)上报成功");
                 }
                 else{
@@ -61,7 +62,7 @@ sub call{
             $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             if(defined $data->{post_api}){
                 my($data,$ua,$tx) = $client->http_post($data->{post_api},json=>$post_json);
-                if($tx->result->is_success){
+                if($tx->res->is_success){
                     $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "]上报成功");
                 }
                 else{
@@ -83,7 +84,7 @@ sub call{
             $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             $client->http_post($data->{post_api},json=>$post_json,sub{
                 my($data,$ua,$tx) = @_;
-                if($tx->result->is_success){
+                if($tx->res->is_success){
                     $client->debug("插件[".__PACKAGE__ ."]事件[".$event."]上报成功");
                 }
                 else{
@@ -102,7 +103,7 @@ sub call{
             $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             $client->http_post($data->{post_api},json=>$post_json,sub{
                 my($data,$ua,$tx) = @_;
-                if($tx->result->is_success){
+                if($tx->res->is_success){
                     $client->debug("插件[".__PACKAGE__ ."]事件[".$event."]上报成功");
                 }
                 else{
@@ -122,7 +123,7 @@ sub call{
             $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             $client->http_post($data->{post_api},json=>$post_json,sub{
                 my($data,$ua,$tx) = @_;
-                if($tx->result->is_success){
+                if($tx->res->is_success){
                     $client->debug("插件[".__PACKAGE__ ."]事件[".$event."]上报成功");
                 }
                 else{
@@ -140,7 +141,7 @@ sub call{
             $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             $client->http_post($data->{post_api},json=>$post_json,sub{
                 my($data,$ua,$tx) = @_;
-                if($tx->result->is_success){
+                if($tx->res->is_success){
                     $client->debug("插件[".__PACKAGE__ ."]事件[".$event."]上报成功");
                 }
                 else{
@@ -166,13 +167,13 @@ sub call{
         $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
         $client->http_post($data->{post_api},json=>$post_json,sub{
             my($data,$ua,$tx) = @_;
-            if($tx->result->is_success){
+            if($tx->res->is_success){
                 $client->debug( $tx->res->body );
-                if($tx->res->headers->content_type =~m#text/json|application/json#){
+                if($tx->res->headers->content_type =~m#(text|application)/json#){
                     #文本类的返回结果必须是json字符串
                     my $json;
                     eval{$json = $client->decode_json($tx->res->body);$client->reform($json)};
-                    if($@){$client->warn($@);return}
+                    if($@){$client->warn("post_api返回的json内容无法正常解析: " . $@);return}
                     if(defined $json){
                         #暂时先不启用format的属性
                         #{code=>0,reply=>"回复的消息",format=>"text"}
@@ -210,7 +211,7 @@ sub call{
         $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
         $client->http_post($data->{post_api},json=>$post_json,sub{
             my($data,$ua,$tx) = @_;
-            if($tx->result->is_success){
+            if($tx->res->is_success){
                 $client->debug("插件[".__PACKAGE__ ."]发送消息[".$msg->id."]上报成功");
                 if($tx->res->headers->content_type =~m#text/json|application/json#){
                     #文本类的返回结果必须是json字符串
